import React from 'react';
import { UseMutateAsyncFunction, QueryObserverResult, RefetchOptions } from 'react-query';
export interface AuthProviderConfig<User = unknown, Error = unknown> {
    key?: string;
    loadUser: (data: any) => Promise<User>;
    loginFn: (data: any) => Promise<User>;
    registerFn: (data: any) => Promise<User>;
    logoutFn: () => Promise<any>;
    waitInitial?: boolean;
    LoaderComponent?: () => JSX.Element;
    ErrorComponent?: ({ error }: {
        error: Error | null;
    }) => JSX.Element;
}
export interface AuthContextValue<User = unknown, Error = unknown, LoginCredentials = unknown, RegisterCredentials = unknown> {
    user: User | undefined;
    login: UseMutateAsyncFunction<User, any, LoginCredentials>;
    logout: UseMutateAsyncFunction<any, any, void, any>;
    register: UseMutateAsyncFunction<User, any, RegisterCredentials>;
    isLoggingIn: boolean;
    isLoggingOut: boolean;
    isRegistering: boolean;
    refetchUser: (options?: RefetchOptions | undefined) => Promise<QueryObserverResult<User, Error>>;
    error: Error | null;
}
export interface AuthProviderProps {
    children: React.ReactNode;
}
export declare function initReactQueryAuth<User = unknown, Error = unknown, LoginCredentials = unknown, RegisterCredentials = unknown>(config: AuthProviderConfig<User, Error>): {
    AuthProvider: ({ children }: AuthProviderProps) => JSX.Element;
    AuthConsumer: React.Consumer<AuthContextValue<User, Error, LoginCredentials, RegisterCredentials> | null>;
    useAuth: () => AuthContextValue<User, Error, LoginCredentials, RegisterCredentials>;
};
