'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = _interopDefault(require('react'));
var reactQuery = require('react-query');

function initReactQueryAuth(config) {
  var AuthContext = React.createContext(null);
  AuthContext.displayName = 'AuthContext';
  var loadUser = config.loadUser,
      loginFn = config.loginFn,
      registerFn = config.registerFn,
      logoutFn = config.logoutFn,
      _config$key = config.key,
      key = _config$key === void 0 ? 'auth-user' : _config$key,
      _config$waitInitial = config.waitInitial,
      waitInitial = _config$waitInitial === void 0 ? true : _config$waitInitial,
      _config$LoaderCompone = config.LoaderComponent,
      LoaderComponent = _config$LoaderCompone === void 0 ? function () {
    return React.createElement("div", null, "Loading...");
  } : _config$LoaderCompone,
      _config$ErrorComponen = config.ErrorComponent,
      ErrorComponent = _config$ErrorComponen === void 0 ? function (error) {
    return React.createElement("div", {
      style: {
        color: 'tomato'
      }
    }, JSON.stringify(error, null, 2));
  } : _config$ErrorComponen;

  function AuthProvider(_ref) {
    var children = _ref.children;
    var queryClient = reactQuery.useQueryClient();

    var _useQuery = reactQuery.useQuery({
      queryKey: key,
      queryFn: loadUser
    }),
        user = _useQuery.data,
        error = _useQuery.error,
        status = _useQuery.status,
        isLoading = _useQuery.isLoading,
        isIdle = _useQuery.isIdle,
        isSuccess = _useQuery.isSuccess,
        refetch = _useQuery.refetch;

    var setUser = React.useCallback(function (data) {
      return queryClient.setQueryData(key, data);
    }, [queryClient]);
    var loginMutation = reactQuery.useMutation({
      mutationFn: loginFn,
      onSuccess: function onSuccess(user) {
        setUser(user);
      }
    });
    var registerMutation = reactQuery.useMutation({
      mutationFn: registerFn,
      onSuccess: function onSuccess(user) {
        setUser(user);
      }
    });
    var logoutMutation = reactQuery.useMutation({
      mutationFn: logoutFn,
      onSuccess: function onSuccess() {
        queryClient.clear();
      }
    });
    var value = React.useMemo(function () {
      return {
        user: user,
        error: error,
        refetchUser: refetch,
        login: loginMutation.mutateAsync,
        isLoggingIn: loginMutation.isLoading,
        logout: logoutMutation.mutateAsync,
        isLoggingOut: logoutMutation.isLoading,
        register: registerMutation.mutateAsync,
        isRegistering: registerMutation.isLoading
      };
    }, [user, error, refetch, loginMutation.mutateAsync, loginMutation.isLoading, logoutMutation.mutateAsync, logoutMutation.isLoading, registerMutation.mutateAsync, registerMutation.isLoading]);

    if (isSuccess || !waitInitial) {
      return React.createElement(AuthContext.Provider, {
        value: value
      }, children);
    }

    if (isLoading || isIdle) {
      return React.createElement(LoaderComponent, null);
    }

    if (error) {
      return React.createElement(ErrorComponent, {
        error: error
      });
    }

    return React.createElement("div", null, "Unhandled status: ", status);
  }

  function useAuth() {
    var context = React.useContext(AuthContext);

    if (!context) {
      throw new Error("useAuth must be used within an AuthProvider");
    }

    return context;
  }

  return {
    AuthProvider: AuthProvider,
    AuthConsumer: AuthContext.Consumer,
    useAuth: useAuth
  };
}

exports.initReactQueryAuth = initReactQueryAuth;
//# sourceMappingURL=react-query-auth.cjs.development.js.map
